0.11 Release                                            Apr. 29. 2014
---------------------------------------------------------------------

* Fixes error in state history reporting

0.10 Release                                            Apr. 29. 2014
---------------------------------------------------------------------

* Support for state transition introspection via CU/Pilot state_history
* Cleaned up an streamlined Input and Outpout file transfer workers
* Support for interchangeable pilot agents
* Closed tickets:
  - https://github.com/radical-cybertools/radical.pilot/issues?milestone=11&state=closed


0.9 Release                                             Apr. 16. 2014
---------------------------------------------------------------------

* Support for output file staging
* Streamlines data model
* More loosely coupled components connected via DB queues
* Closed tickets:
  - https://github.com/radical-cybertools/radical.pilot/issues?milestone=10&state=closed


0.8 Release                                             Mar. 24. 2014
---------------------------------------------------------------------

* Renamed codebase from sagapilot to radical.pilot
* Added explicit close() calls to PM, UM and Session.
* Cloesed tickets:
  - https://github.com/radical-cybertools/radical.pilot/issues?milestone=9&state=closed


0.7 Release                                             Feb. 25. 2014
---------------------------------------------------------------------

* Added support for callbacks 
* Added support for input file transfer !
* Closed tickets:
  - https://github.com/radical-cybertools/radical.pilot/issues?milestone=8&state=closed


0.6 Release                                             Feb. 24. 2014
---------------------------------------------------------------------

* BROKEN RELEASE


0.5 Release                                             Feb. 06. 2014
---------------------------------------------------------------------

* Tutorial 2 release (Github only)
* Added support for multiprocessing worker
* Support for CU stdout and stderr transfer via MongoDB GridFS
* Closed tickets:
  - https://github.com/saga-project/saga-pilot/issues?milestone=7&page=1&state=closed


0.4 Release 
---------------------------------------------------------------------

* Tutorial 1 release (Github only)
* Consistent naming (sagapilot instead of sinon)


0.1.3 Release 
---------------------------------------------------------------------

* Github only release: 
  pip install --upgrade -e git://github.com/saga-project/saga-pilot.git@master#egg=saga-pilot 

* Added logging
* Added security credential handling 
* Closed tickets: 
  - https://github.com/saga-project/saga-pilot/issues?milestone=3&state=closed


0.1.2 Release 
---------------------------------------------------------------------

* Github only release: 
  pip install --upgrade -e git://github.com/saga-project/saga-pilot.git@master#egg=saga-pilot 

* Closed tickets: 
  - https://github.com/saga-project/saga-pilot/issues?milestone=4&state=closed
